@@ -26,10 +26,10 @@
 #' @seealso related: \code{\link{ee_photos}} \code{\link{california_counties}}
 #' @examples
 #' # Request all photos. This request will paginate. 
-#' merced <- ee_photos(county = "Merced County")
+#' # merced <- ee_photos(county = "Merced County")
 #' # ee_photos()
 #' # Search by collection code. See notes above on options
-#' # ee_photos(collection_code = "CalAcademy")
+#'  ee_photos(collection_code = "CalAcademy")
 #' # ee_photos(collection_code = "VTM")
 #' # ee_photos(collection_code = "CalFlora")
 #' # ee_photos(collection_code = "CDFA")
@@ -72,7 +72,7 @@ ee_photos <- function(page = NULL,
 	photos_url <- "http://ecoengine.berkeley.edu/api/photos/?format=json"
 	if(georeferenced) georeferenced = "True"
 	
-	args <- as.list(compact(c(page_size = page_size,					 
+	args <- as.list(ee_compact(c(page_size = page_size,					 
 							state_province = state_province, 
 						 	county = county, 
 						 	genus = genus, 
