@@ -1,4 +1,39 @@
 
+#' ee_cbind
+#'
+#' Allows for combining split ecoengine calls (e.g. paginated calls) back into one single result object
+#' @param results <what param does>
+#' @export
+#' @importFrom assertthat assert_that
+#' @examples \dontrun{
+#' x1 <- ee_observations(genus = "Lynx", page = 1)
+#' x2 <- ee_observations(genus = "Lynx", page = 2)
+#' x12 <- ee_cbind(list(x1, x2))
+#'}
+ee_cbind <- function(results) {
+    assert_that(class(results) == "list")
+    res2 <- ldply(results, function(x) {
+        y <- x[-4]
+        data.frame(LinearizeNestedList(y))
+    })
+
+    page_loc <- which(names(res2) == "call.page")
+    if(nrow(res2[!duplicated(res2[, -page_loc]), ]) == 1) {
+        data <- ldply(results, function(x) x[[4]])
+        res <- results[[1]]
+        res$data <- data
+        # Next two lines add pages back. Combines all pages, sorts, then adds.
+        pages <- res2$call.page
+        res$call$page <- paste0(pages[order(pages)], collapse = " ")
+        res
+    } else {
+        stop("Cannot combine results from unidentical calls")
+    }
+
+}
+
+
+
 #' Print a summary for an ecoengine object
 #' @method print ecoengine
 #' @S3method print ecoengine
@@ -6,11 +41,11 @@
 #'   
 #' @param ... additional arguments
 print.ecoengine <- function(x, ...) {
-cat(sprintf("[Total results]: %s \n", x$results))
+cat(sprintf("[Total results on the server]: %s \n", x$results))
 cat("[Args]: \n")
 suppressWarnings(pretty_lists(x$call))
 cat(sprintf("[Type]: %s \n", x$type))
-cat(sprintf("[Number of results]: %s \n", nrow(x$data)))
+cat(sprintf("[Number of results retrieved]: %s \n", nrow(x$data)))
 }
 
 
@@ -36,6 +71,7 @@ ee_pages <- function(ee, page_size = 25) {
 #'Takes a page range and total number of observations to return the right sequence of pages that need to be crawled.
 #' @param page requested page number or page range. Can also be "all"
 #' @param  total_obs Total number of records available for any search query
+#' @param  page_size Default is \code{25}. Set higher if needed.
 #' @export
 #' @examples \dontrun{
 #' ee_paginator(1, 100)
@@ -45,9 +81,9 @@ ee_pages <- function(ee, page_size = 25) {
 #' # This will return an error since there are only 4 pages per 100 observations
 #' ee_paginator(1:5, 100)
 #' }
-ee_paginator <- function(page, total_obs) {
-        all_pages <- ceiling(total_obs/25)
-        if(total_obs < 25) { req_pages <- 1 }
+ee_paginator <- function(page, total_obs, page_size = 25) {
+        all_pages <- ceiling(total_obs/page_size)
+        if(total_obs < page_size) { req_pages <- 1 }
         if(identical(page, "all")) { req_pages <- seq_along(1: all_pages)}
         if(length(page) == 1 & identical(class(page), "numeric")) { req_pages <- page }
         if(identical(class(page), "integer")) {
